{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Article where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CreativeWork
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.NewsArticle
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Report
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ScholarlyArticle
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SocialMediaPosting
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TechArticle

-- | An article, such as a news article or piece of investigative report. Newspapers and magazines have articles of many different types and this is intended to cover them all.      See also blog post.
--
--   [@id@] Article
--
--   [@label@] Article
--
--   [@comment@] An article, such as a news article or piece of investigative report. Newspapers and magazines have articles of many different types and this is intended to cover them all.      <br/><br/>See also <a href=\"http://blog.schema.org/2014/09/schemaorg-support-for-bibliographic_2.html\">blog post</a>.
--
--   [@ancestors@] @'Thing','CreativeWork'@
--
--   [@subtypes@] @'NewsArticle','Report','ScholarlyArticle','SocialMediaPosting','TechArticle'@
--
--   [@supertypes@] @'CreativeWork'@
--
--   [@url@] <http://schema.org/Article>
data Article = Article { articleBody :: ArticleBody
                       , articleSection :: ArticleSection
                       , pageEnd :: PageEnd
                       , pageStart :: PageStart
                       , pagination :: Pagination
                       , wordCount :: WordCount
                       , about :: About
                       , accessibilityAPI :: AccessibilityAPI
                       , accessibilityControl :: AccessibilityControl
                       , accessibilityFeature :: AccessibilityFeature
                       , accessibilityHazard :: AccessibilityHazard
                       , accountablePerson :: AccountablePerson
                       , aggregateRating :: AggregateRating
                       , alternativeHeadline :: AlternativeHeadline
                       , associatedMedia :: AssociatedMedia
                       , audience :: Audience
                       , audio :: Audio
                       , author :: Author
                       , award :: Award
                       , character :: Character
                       , citation :: Citation
                       , comment :: Comment
                       , commentCount :: CommentCount
                       , contentLocation :: ContentLocation
                       , contentRating :: ContentRating
                       , contributor :: Contributor
                       , copyrightHolder :: CopyrightHolder
                       , copyrightYear :: CopyrightYear
                       , creator :: Creator
                       , dateCreated :: DateCreated
                       , dateModified :: DateModified
                       , datePublished :: DatePublished
                       , discussionUrl :: DiscussionUrl
                       , editor :: Editor
                       , educationalAlignment :: EducationalAlignment
                       , educationalUse :: EducationalUse
                       , encoding :: Encoding
                       , exampleOfWork :: ExampleOfWork
                       , fileFormat :: FileFormat
                       , genre :: Genre
                       , hasPart :: HasPart
                       , headline :: Headline
                       , inLanguage :: InLanguage
                       , interactionStatistic :: InteractionStatistic
                       , interactivityType :: InteractivityType
                       , isBasedOnUrl :: IsBasedOnUrl
                       , isFamilyFriendly :: IsFamilyFriendly
                       , isPartOf :: IsPartOf
                       , keywords :: Keywords
                       , learningResourceType :: LearningResourceType
                       , license :: License
                       , locationCreated :: LocationCreated
                       , mainEntity :: MainEntity
                       , mentions :: Mentions
                       , offers :: Offers
                       , position :: Position
                       , producer :: Producer
                       , provider :: Provider
                       , publication :: Publication
                       , publisher :: Publisher
                       , publishingPrinciples :: PublishingPrinciples
                       , recordedAt :: RecordedAt
                       , releasedEvent :: ReleasedEvent
                       , review :: Review
                       , schemaVersion :: SchemaVersion
                       , sourceOrganization :: SourceOrganization
                       , text :: Text
                       , thumbnailUrl :: ThumbnailUrl
                       , timeRequired :: TimeRequired
                       , translator :: Translator
                       , typicalAgeRange :: TypicalAgeRange
                       , version :: Version
                       , video :: Video
                       , workExample :: WorkExample
                       , additionalType :: AdditionalType
                       , alternateName :: AlternateName
                       , description :: Description
                       , image :: Image
                       , mainEntityOfPage :: MainEntityOfPage
                       , name :: Name
                       , potentialAction :: PotentialAction
                       , sameAs :: SameAs
                       , url :: Url
                       }
               deriving (Show, Read, Eq, Typeable)

instance MetaData Article where
  _label         = const "Article"
  _comment_plain = const "An article, such as a news article or piece of investigative report. Newspapers and magazines have articles of many different types and this is intended to cover them all.      See also blog post."
  _comment       = const "An article, such as a news article or piece of investigative report. Newspapers and magazines have articles of many different types and this is intended to cover them all.      <br/><br/>See also <a href=\"http://blog.schema.org/2014/09/schemaorg-support-for-bibliographic_2.html\">blog post</a>."
  _url           = const "http://schema.org/Article"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.NewsArticle.NewsArticle)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Report.Report)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ScholarlyArticle.ScholarlyArticle)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SocialMediaPosting.SocialMediaPosting)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TechArticle.TechArticle)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)]