{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.BroadcastEvent where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Event
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PublicationEvent

-- | An over the air or online broadcast event.
--
--   [@id@] BroadcastEvent
--
--   [@label@] Broadcast Event
--
--   [@comment@] An over the air or online broadcast event.
--
--   [@ancestors@] @'Thing','Event','PublicationEvent'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'PublicationEvent'@
--
--   [@url@] <http://schema.org/BroadcastEvent>
data BroadcastEvent = BroadcastEvent { broadcastOfEvent :: BroadcastOfEvent
                                     , isLiveBroadcast :: IsLiveBroadcast
                                     , videoFormat :: VideoFormat
                                     , isAccessibleForFree :: IsAccessibleForFree
                                     , publishedOn :: PublishedOn
                                     , aggregateRating :: AggregateRating
                                     , attendee :: Attendee
                                     , doorTime :: DoorTime
                                     , duration :: Duration
                                     , endDate :: EndDate
                                     , eventStatus :: EventStatus
                                     , inLanguage :: InLanguage
                                     , location :: Location
                                     , offers :: Offers
                                     , organizer :: Organizer
                                     , performer :: Performer
                                     , previousStartDate :: PreviousStartDate
                                     , recordedIn :: RecordedIn
                                     , review :: Review
                                     , startDate :: StartDate
                                     , subEvent :: SubEvent
                                     , superEvent :: SuperEvent
                                     , typicalAgeRange :: TypicalAgeRange
                                     , workFeatured :: WorkFeatured
                                     , workPerformed :: WorkPerformed
                                     , additionalType :: AdditionalType
                                     , alternateName :: AlternateName
                                     , description :: Description
                                     , image :: Image
                                     , mainEntityOfPage :: MainEntityOfPage
                                     , name :: Name
                                     , potentialAction :: PotentialAction
                                     , sameAs :: SameAs
                                     , url :: Url
                                     }
                      deriving (Show, Read, Eq, Typeable)

instance MetaData BroadcastEvent where
  _label         = const "Broadcast Event"
  _comment_plain = const "An over the air or online broadcast event."
  _comment       = const "An over the air or online broadcast event."
  _url           = const "http://schema.org/BroadcastEvent"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Event.Event)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PublicationEvent.PublicationEvent)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.PublicationEvent.PublicationEvent)]