{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.BusinessFunction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type hiding (BusinessFunction)
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Enumeration

-- | The business function specifies the type of activity or access (i.e., the bundle of rights) offered by the organization or business person through the offer. Typical are sell, rental or lease, maintenance or repair, manufacture / produce, recycle / dispose, engineering / construction, or installation. Proprietary specifications of access rights are also instances of this class.    Commonly used values:    http://purl.org/goodrelations/v1#ConstructionInstallation     http://purl.org/goodrelations/v1#Dispose     http://purl.org/goodrelations/v1#LeaseOut     http://purl.org/goodrelations/v1#Maintain     http://purl.org/goodrelations/v1#ProvideService     http://purl.org/goodrelations/v1#Repair     http://purl.org/goodrelations/v1#Sell     http://purl.org/goodrelations/v1#Buy
--
--   [@id@] BusinessFunction
--
--   [@label@] Business Function
--
--   [@comment@] The business function specifies the type of activity or access (i.e., the bundle of rights) offered by the organization or business person through the offer. Typical are sell, rental or lease, maintenance or repair, manufacture / produce, recycle / dispose, engineering / construction, or installation. Proprietary specifications of access rights are also instances of this class.<br/>    Commonly used values:<br/><br/>    http://purl.org/goodrelations/v1#ConstructionInstallation <br/>    http://purl.org/goodrelations/v1#Dispose <br/>    http://purl.org/goodrelations/v1#LeaseOut <br/>    http://purl.org/goodrelations/v1#Maintain <br/>    http://purl.org/goodrelations/v1#ProvideService <br/>    http://purl.org/goodrelations/v1#Repair <br/>    http://purl.org/goodrelations/v1#Sell <br/>    http://purl.org/goodrelations/v1#Buy <br/>        
--
--   [@ancestors@] @'Thing','Intangible','Enumeration'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Enumeration'@
--
--   [@url@] <http://schema.org/BusinessFunction>
data BusinessFunction = BusinessFunction { supersededBy :: SupersededBy
                                         , additionalType :: AdditionalType
                                         , alternateName :: AlternateName
                                         , description :: Description
                                         , image :: Image
                                         , mainEntityOfPage :: MainEntityOfPage
                                         , name :: Name
                                         , potentialAction :: PotentialAction
                                         , sameAs :: SameAs
                                         , url :: Url
                                         }
                        deriving (Show, Read, Eq, Typeable)

instance MetaData BusinessFunction where
  _label         = const "Business Function"
  _comment_plain = const "The business function specifies the type of activity or access (i.e., the bundle of rights) offered by the organization or business person through the offer. Typical are sell, rental or lease, maintenance or repair, manufacture / produce, recycle / dispose, engineering / construction, or installation. Proprietary specifications of access rights are also instances of this class.    Commonly used values:    http://purl.org/goodrelations/v1#ConstructionInstallation     http://purl.org/goodrelations/v1#Dispose     http://purl.org/goodrelations/v1#LeaseOut     http://purl.org/goodrelations/v1#Maintain     http://purl.org/goodrelations/v1#ProvideService     http://purl.org/goodrelations/v1#Repair     http://purl.org/goodrelations/v1#Sell     http://purl.org/goodrelations/v1#Buy"
  _comment       = const "The business function specifies the type of activity or access (i.e., the bundle of rights) offered by the organization or business person through the offer. Typical are sell, rental or lease, maintenance or repair, manufacture / produce, recycle / dispose, engineering / construction, or installation. Proprietary specifications of access rights are also instances of this class.<br/>    Commonly used values:<br/><br/>    http://purl.org/goodrelations/v1#ConstructionInstallation <br/>    http://purl.org/goodrelations/v1#Dispose <br/>    http://purl.org/goodrelations/v1#LeaseOut <br/>    http://purl.org/goodrelations/v1#Maintain <br/>    http://purl.org/goodrelations/v1#ProvideService <br/>    http://purl.org/goodrelations/v1#Repair <br/>    http://purl.org/goodrelations/v1#Sell <br/>    http://purl.org/goodrelations/v1#Buy <br/>        "
  _url           = const "http://schema.org/BusinessFunction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)]