{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ControlAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ActivateAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DeactivateAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ResumeAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SuspendAction

-- | An agent controls a device or application.
--
--   [@id@] ControlAction
--
--   [@label@] Control Action
--
--   [@comment@] An agent controls a device or application.
--
--   [@ancestors@] @'Thing','Action'@
--
--   [@subtypes@] @'ActivateAction','DeactivateAction','ResumeAction','SuspendAction'@
--
--   [@supertypes@] @'Action'@
--
--   [@url@] <http://schema.org/ControlAction>
data ControlAction = ControlAction { actionStatus :: ActionStatus
                                   , agent :: Agent
                                   , endTime :: EndTime
                                   , error :: Error
                                   , instrument :: Instrument
                                   , location :: Location
                                   , object :: Object
                                   , participant :: Participant
                                   , result :: Result
                                   , startTime :: StartTime
                                   , target :: Target
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData ControlAction where
  _label         = const "Control Action"
  _comment_plain = const "An agent controls a device or application."
  _comment       = const "An agent controls a device or application."
  _url           = const "http://schema.org/ControlAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ActivateAction.ActivateAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DeactivateAction.DeactivateAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ResumeAction.ResumeAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SuspendAction.SuspendAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]