{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.CreativeWorkSeries where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CreativeWork
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BookSeries
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MovieSeries
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Periodical
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RadioSeries
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TVSeries
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.VideoGameSeries

-- | A CreativeWorkSeries in schema.org is a group of related items, typically but not necessarily of the same kind.          CreativeWorkSeries are usually organized into some order, often chronological. Unlike ItemList which          is a general purpose data structure for lists of things, the emphasis with          CreativeWorkSeries is on published materials (written e.g. books and periodicals,          or media such as tv, radio and games).                    Specific subtypes are available for describing TVSeries, RadioSeries,          MovieSeries,          BookSeries,          Periodical          and VideoGameSeries. In each case,          the hasPart / isPartOf properties          can be used to relate the CreativeWorkSeries to its parts. The general CreativeWorkSeries type serves largely          just to organize these more specific and practical subtypes.                    It is common for properties applicable to an item from the series to be usefully applied to the containing group.          Schema.org attempts to anticipate some of these cases, but publishers should be free to apply          properties of the series parts to the series as a whole wherever they seem appropriate.
--
--   [@id@] CreativeWorkSeries
--
--   [@label@] Creative Work Series
--
--   [@comment@]           A CreativeWorkSeries in schema.org is a group of related items, typically but not necessarily of the same kind.          CreativeWorkSeries are usually organized into some order, often chronological. Unlike <a href=\"http://schema.org/ItemList\">ItemList</a> which          is a general purpose data structure for lists of things, the emphasis with          CreativeWorkSeries is on published materials (written e.g. books and periodicals,          or media such as tv, radio and games).          <br/><br/>          Specific subtypes are available for describing <a href=\"http://schema.org/TVSeries\">TVSeries</a>, <a href=\"http://schema.org/RadioSeries\">RadioSeries</a>,          <a href=\"http://schema.org/MovieSeries\">MovieSeries</a>,          <a href=\"http://schema.org/BookSeries\">BookSeries</a>,          <a href=\"http://schema.org/Periodical\">Periodical</a>          and <a href=\"http://schema.org/VideoGameSeries\">VideoGameSeries</a>. In each case,          the <a href=\"http://schema.org/hasPart\">hasPart</a> / <a href=\"http://schema.org/isPartOf\">isPartOf</a> properties          can be used to relate the CreativeWorkSeries to its parts. The general CreativeWorkSeries type serves largely          just to organize these more specific and practical subtypes.          <br/><br/>          It is common for properties applicable to an item from the series to be usefully applied to the containing group.          Schema.org attempts to anticipate some of these cases, but publishers should be free to apply          properties of the series parts to the series as a whole wherever they seem appropriate.
--
--   [@ancestors@] @'Thing','CreativeWork'@
--
--   [@subtypes@] @'BookSeries','MovieSeries','Periodical','RadioSeries','TVSeries','VideoGameSeries'@
--
--   [@supertypes@] @'CreativeWork'@
--
--   [@url@] <http://schema.org/CreativeWorkSeries>
data CreativeWorkSeries = CreativeWorkSeries { endDate :: EndDate
                                             , startDate :: StartDate
                                             , about :: About
                                             , accessibilityAPI :: AccessibilityAPI
                                             , accessibilityControl :: AccessibilityControl
                                             , accessibilityFeature :: AccessibilityFeature
                                             , accessibilityHazard :: AccessibilityHazard
                                             , accountablePerson :: AccountablePerson
                                             , aggregateRating :: AggregateRating
                                             , alternativeHeadline :: AlternativeHeadline
                                             , associatedMedia :: AssociatedMedia
                                             , audience :: Audience
                                             , audio :: Audio
                                             , author :: Author
                                             , award :: Award
                                             , character :: Character
                                             , citation :: Citation
                                             , comment :: Comment
                                             , commentCount :: CommentCount
                                             , contentLocation :: ContentLocation
                                             , contentRating :: ContentRating
                                             , contributor :: Contributor
                                             , copyrightHolder :: CopyrightHolder
                                             , copyrightYear :: CopyrightYear
                                             , creator :: Creator
                                             , dateCreated :: DateCreated
                                             , dateModified :: DateModified
                                             , datePublished :: DatePublished
                                             , discussionUrl :: DiscussionUrl
                                             , editor :: Editor
                                             , educationalAlignment :: EducationalAlignment
                                             , educationalUse :: EducationalUse
                                             , encoding :: Encoding
                                             , exampleOfWork :: ExampleOfWork
                                             , fileFormat :: FileFormat
                                             , genre :: Genre
                                             , hasPart :: HasPart
                                             , headline :: Headline
                                             , inLanguage :: InLanguage
                                             , interactionStatistic :: InteractionStatistic
                                             , interactivityType :: InteractivityType
                                             , isBasedOnUrl :: IsBasedOnUrl
                                             , isFamilyFriendly :: IsFamilyFriendly
                                             , isPartOf :: IsPartOf
                                             , keywords :: Keywords
                                             , learningResourceType :: LearningResourceType
                                             , license :: License
                                             , locationCreated :: LocationCreated
                                             , mainEntity :: MainEntity
                                             , mentions :: Mentions
                                             , offers :: Offers
                                             , position :: Position
                                             , producer :: Producer
                                             , provider :: Provider
                                             , publication :: Publication
                                             , publisher :: Publisher
                                             , publishingPrinciples :: PublishingPrinciples
                                             , recordedAt :: RecordedAt
                                             , releasedEvent :: ReleasedEvent
                                             , review :: Review
                                             , schemaVersion :: SchemaVersion
                                             , sourceOrganization :: SourceOrganization
                                             , text :: Text
                                             , thumbnailUrl :: ThumbnailUrl
                                             , timeRequired :: TimeRequired
                                             , translator :: Translator
                                             , typicalAgeRange :: TypicalAgeRange
                                             , version :: Version
                                             , video :: Video
                                             , workExample :: WorkExample
                                             , additionalType :: AdditionalType
                                             , alternateName :: AlternateName
                                             , description :: Description
                                             , image :: Image
                                             , mainEntityOfPage :: MainEntityOfPage
                                             , name :: Name
                                             , potentialAction :: PotentialAction
                                             , sameAs :: SameAs
                                             , url :: Url
                                             }
                          deriving (Show, Read, Eq, Typeable)

instance MetaData CreativeWorkSeries where
  _label         = const "Creative Work Series"
  _comment_plain = const "A CreativeWorkSeries in schema.org is a group of related items, typically but not necessarily of the same kind.          CreativeWorkSeries are usually organized into some order, often chronological. Unlike ItemList which          is a general purpose data structure for lists of things, the emphasis with          CreativeWorkSeries is on published materials (written e.g. books and periodicals,          or media such as tv, radio and games).                    Specific subtypes are available for describing TVSeries, RadioSeries,          MovieSeries,          BookSeries,          Periodical          and VideoGameSeries. In each case,          the hasPart / isPartOf properties          can be used to relate the CreativeWorkSeries to its parts. The general CreativeWorkSeries type serves largely          just to organize these more specific and practical subtypes.                    It is common for properties applicable to an item from the series to be usefully applied to the containing group.          Schema.org attempts to anticipate some of these cases, but publishers should be free to apply          properties of the series parts to the series as a whole wherever they seem appropriate."
  _comment       = const "          A CreativeWorkSeries in schema.org is a group of related items, typically but not necessarily of the same kind.          CreativeWorkSeries are usually organized into some order, often chronological. Unlike <a href=\"http://schema.org/ItemList\">ItemList</a> which          is a general purpose data structure for lists of things, the emphasis with          CreativeWorkSeries is on published materials (written e.g. books and periodicals,          or media such as tv, radio and games).          <br/><br/>          Specific subtypes are available for describing <a href=\"http://schema.org/TVSeries\">TVSeries</a>, <a href=\"http://schema.org/RadioSeries\">RadioSeries</a>,          <a href=\"http://schema.org/MovieSeries\">MovieSeries</a>,          <a href=\"http://schema.org/BookSeries\">BookSeries</a>,          <a href=\"http://schema.org/Periodical\">Periodical</a>          and <a href=\"http://schema.org/VideoGameSeries\">VideoGameSeries</a>. In each case,          the <a href=\"http://schema.org/hasPart\">hasPart</a> / <a href=\"http://schema.org/isPartOf\">isPartOf</a> properties          can be used to relate the CreativeWorkSeries to its parts. The general CreativeWorkSeries type serves largely          just to organize these more specific and practical subtypes.          <br/><br/>          It is common for properties applicable to an item from the series to be usefully applied to the containing group.          Schema.org attempts to anticipate some of these cases, but publishers should be free to apply          properties of the series parts to the series as a whole wherever they seem appropriate."
  _url           = const "http://schema.org/CreativeWorkSeries"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BookSeries.BookSeries)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MovieSeries.MovieSeries)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Periodical.Periodical)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RadioSeries.RadioSeries)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TVSeries.TVSeries)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.VideoGameSeries.VideoGameSeries)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)]