{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.EntertainmentBusiness where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type hiding (EntertainmentBusiness)
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EntertainmentBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AdultEntertainment
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AmusementPark
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ArtGallery
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Casino
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ComedyClub
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MovieTheater
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.NightClub

-- | A business providing entertainment.
--
--   [@id@] EntertainmentBusiness
--
--   [@label@] Entertainment Business
--
--   [@comment@] A business providing entertainment.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','EntertainmentBusiness','Thing','Place','LocalBusiness'@
--
--   [@subtypes@] @'AdultEntertainment','AmusementPark','ArtGallery','Casino','ComedyClub','MovieTheater','NightClub'@
--
--   [@supertypes@] @'LocalBusiness'@
--
--   [@url@] <http://schema.org/EntertainmentBusiness>
data EntertainmentBusiness = EntertainmentBusiness { branchCode :: BranchCode
                                                   , currenciesAccepted :: CurrenciesAccepted
                                                   , openingHours :: OpeningHours
                                                   , paymentAccepted :: PaymentAccepted
                                                   , priceRange :: PriceRange
                                                   , additionalProperty :: AdditionalProperty
                                                   , address :: Address
                                                   , aggregateRating :: AggregateRating
                                                   , branchCode :: BranchCode
                                                   , containedInPlace :: ContainedInPlace
                                                   , containsPlace :: ContainsPlace
                                                   , event :: Event
                                                   , faxNumber :: FaxNumber
                                                   , geo :: Geo
                                                   , globalLocationNumber :: GlobalLocationNumber
                                                   , hasMap :: HasMap
                                                   , isicV4 :: IsicV4
                                                   , logo :: Logo
                                                   , openingHoursSpecification :: OpeningHoursSpecification
                                                   , photo :: Photo
                                                   , review :: Review
                                                   , telephone :: Telephone
                                                   , address :: Address
                                                   , aggregateRating :: AggregateRating
                                                   , alumni :: Alumni
                                                   , areaServed :: AreaServed
                                                   , award :: Award
                                                   , brand :: Brand
                                                   , contactPoint :: ContactPoint
                                                   , department :: Department
                                                   , dissolutionDate :: DissolutionDate
                                                   , duns :: Duns
                                                   , email :: Email
                                                   , employee :: Employee
                                                   , event :: Event
                                                   , faxNumber :: FaxNumber
                                                   , founder :: Founder
                                                   , foundingDate :: FoundingDate
                                                   , foundingLocation :: FoundingLocation
                                                   , globalLocationNumber :: GlobalLocationNumber
                                                   , hasOfferCatalog :: HasOfferCatalog
                                                   , hasPOS :: HasPOS
                                                   , isicV4 :: IsicV4
                                                   , legalName :: LegalName
                                                   , location :: Location
                                                   , logo :: Logo
                                                   , makesOffer :: MakesOffer
                                                   , member :: Member
                                                   , memberOf :: MemberOf
                                                   , naics :: Naics
                                                   , numberOfEmployees :: NumberOfEmployees
                                                   , owns :: Owns
                                                   , parentOrganization :: ParentOrganization
                                                   , review :: Review
                                                   , seeks :: Seeks
                                                   , subOrganization :: SubOrganization
                                                   , taxID :: TaxID
                                                   , telephone :: Telephone
                                                   , vatID :: VatID
                                                   , additionalType :: AdditionalType
                                                   , alternateName :: AlternateName
                                                   , description :: Description
                                                   , image :: Image
                                                   , mainEntityOfPage :: MainEntityOfPage
                                                   , name :: Name
                                                   , potentialAction :: PotentialAction
                                                   , sameAs :: SameAs
                                                   , url :: Url
                                                   }
                             deriving (Show, Read, Eq, Typeable)

instance MetaData EntertainmentBusiness where
  _label         = const "Entertainment Business"
  _comment_plain = const "A business providing entertainment."
  _comment       = const "A business providing entertainment."
  _url           = const "http://schema.org/EntertainmentBusiness"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EntertainmentBusiness.EntertainmentBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AdultEntertainment.AdultEntertainment)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AmusementPark.AmusementPark)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ArtGallery.ArtGallery)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Casino.Casino)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ComedyClub.ComedyClub)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MovieTheater.MovieTheater)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.NightClub.NightClub)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)]