{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Invoice where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | A statement of the money due for goods or services; a bill.
--
--   [@id@] Invoice
--
--   [@label@] Invoice
--
--   [@comment@] A statement of the money due for goods or services; a bill.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Invoice>
data Invoice = Invoice { accountId :: AccountId
                       , billingPeriod :: BillingPeriod
                       , broker :: Broker
                       , category :: Category
                       , confirmationNumber :: ConfirmationNumber
                       , customer :: Customer
                       , minimumPaymentDue :: MinimumPaymentDue
                       , paymentDueDate :: PaymentDueDate
                       , paymentMethod :: PaymentMethod
                       , paymentMethodId :: PaymentMethodId
                       , paymentStatus :: PaymentStatus
                       , provider :: Provider
                       , referencesOrder :: ReferencesOrder
                       , scheduledPaymentDate :: ScheduledPaymentDate
                       , totalPaymentDue :: TotalPaymentDue
                       , additionalType :: AdditionalType
                       , alternateName :: AlternateName
                       , description :: Description
                       , image :: Image
                       , mainEntityOfPage :: MainEntityOfPage
                       , name :: Name
                       , potentialAction :: PotentialAction
                       , sameAs :: SameAs
                       , url :: Url
                       }
               deriving (Show, Read, Eq, Typeable)

instance MetaData Invoice where
  _label         = const "Invoice"
  _comment_plain = const "A statement of the money due for goods or services; a bill."
  _comment       = const "A statement of the money due for goods or services; a bill."
  _url           = const "http://schema.org/Invoice"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]