{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.MedicalCondition where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InfectiousDisease

-- | Any condition of the human body that affects the normal functioning of a person, whether physically or mentally. Includes diseases, injuries, disabilities, disorders, syndromes, etc.
--
--   [@id@] MedicalCondition
--
--   [@label@] Medical Condition
--
--   [@comment@] Any condition of the human body that affects the normal functioning of a person, whether physically or mentally. Includes diseases, injuries, disabilities, disorders, syndromes, etc.
--
--   [@ancestors@] @'Thing','MedicalEntity'@
--
--   [@subtypes@] @'InfectiousDisease'@
--
--   [@supertypes@] @'MedicalEntity'@
--
--   [@url@] <http://schema.org/MedicalCondition>
data MedicalCondition = MedicalCondition { associatedAnatomy :: AssociatedAnatomy
                                         , cause :: Cause
                                         , differentialDiagnosis :: DifferentialDiagnosis
                                         , epidemiology :: Epidemiology
                                         , expectedPrognosis :: ExpectedPrognosis
                                         , naturalProgression :: NaturalProgression
                                         , pathophysiology :: Pathophysiology
                                         , possibleComplication :: PossibleComplication
                                         , possibleTreatment :: PossibleTreatment
                                         , primaryPrevention :: PrimaryPrevention
                                         , riskFactor :: RiskFactor
                                         , secondaryPrevention :: SecondaryPrevention
                                         , signOrSymptom :: SignOrSymptom
                                         , stage :: Stage
                                         , subtype :: Subtype
                                         , typicalTest :: TypicalTest
                                         , code :: Code
                                         , guideline :: Guideline
                                         , medicineSystem :: MedicineSystem
                                         , recognizingAuthority :: RecognizingAuthority
                                         , relevantSpecialty :: RelevantSpecialty
                                         , study :: Study
                                         , additionalType :: AdditionalType
                                         , alternateName :: AlternateName
                                         , description :: Description
                                         , image :: Image
                                         , mainEntityOfPage :: MainEntityOfPage
                                         , name :: Name
                                         , potentialAction :: PotentialAction
                                         , sameAs :: SameAs
                                         , url :: Url
                                         }
                        deriving (Show, Read, Eq, Typeable)

instance MetaData MedicalCondition where
  _label         = const "Medical Condition"
  _comment_plain = const "Any condition of the human body that affects the normal functioning of a person, whether physically or mentally. Includes diseases, injuries, disabilities, disorders, syndromes, etc."
  _comment       = const "Any condition of the human body that affects the normal functioning of a person, whether physically or mentally. Includes diseases, injuries, disabilities, disorders, syndromes, etc."
  _url           = const "http://schema.org/MedicalCondition"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.InfectiousDisease.InfectiousDisease)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)]