{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.MedicalDevice where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity

-- | Any object used in a medical capacity, such as to diagnose or treat a patient.
--
--   [@id@] MedicalDevice
--
--   [@label@] Medical Device
--
--   [@comment@] Any object used in a medical capacity, such as to diagnose or treat a patient.
--
--   [@ancestors@] @'Thing','MedicalEntity'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalEntity'@
--
--   [@url@] <http://schema.org/MedicalDevice>
data MedicalDevice = MedicalDevice { adverseOutcome :: AdverseOutcome
                                   , contraindication :: Contraindication
                                   , indication :: Indication
                                   , postOp :: PostOp
                                   , preOp :: PreOp
                                   , procedure :: Procedure
                                   , purpose :: Purpose
                                   , seriousAdverseOutcome :: SeriousAdverseOutcome
                                   , code :: Code
                                   , guideline :: Guideline
                                   , medicineSystem :: MedicineSystem
                                   , recognizingAuthority :: RecognizingAuthority
                                   , relevantSpecialty :: RelevantSpecialty
                                   , study :: Study
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData MedicalDevice where
  _label         = const "Medical Device"
  _comment_plain = const "Any object used in a medical capacity, such as to diagnose or treat a patient."
  _comment       = const "Any object used in a medical capacity, such as to diagnose or treat a patient."
  _url           = const "http://schema.org/MedicalDevice"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)]