{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.MedicalDevicePurpose where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Enumeration
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalDevicePurpose
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEnumeration
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalIntangible

-- | Categories of medical devices, organized by the purpose or intended use of the device.
--
--   [@id@] MedicalDevicePurpose
--
--   [@label@] Medical Device Purpose
--
--   [@comment@] Categories of medical devices, organized by the purpose or intended use of the device.
--
--   [@ancestors@] @'Thing','Intangible','Enumeration','MedicalDevicePurpose','Thing','Intangible','Enumeration','MedicalEnumeration','MedicalDevicePurpose','Thing','MedicalEntity','MedicalIntangible','MedicalEnumeration'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Enumeration','MedicalEnumeration'@
--
--   [@url@] <http://schema.org/MedicalDevicePurpose>
data MedicalDevicePurpose = MedicalDevicePurpose { supersededBy :: SupersededBy
                                                 , code :: Code
                                                 , guideline :: Guideline
                                                 , medicineSystem :: MedicineSystem
                                                 , recognizingAuthority :: RecognizingAuthority
                                                 , relevantSpecialty :: RelevantSpecialty
                                                 , study :: Study
                                                 , additionalType :: AdditionalType
                                                 , alternateName :: AlternateName
                                                 , description :: Description
                                                 , image :: Image
                                                 , mainEntityOfPage :: MainEntityOfPage
                                                 , name :: Name
                                                 , potentialAction :: PotentialAction
                                                 , sameAs :: SameAs
                                                 , url :: Url
                                                 }
                            deriving (Show, Read, Eq, Typeable)

instance MetaData MedicalDevicePurpose where
  _label         = const "Medical Device Purpose"
  _comment_plain = const "Categories of medical devices, organized by the purpose or intended use of the device."
  _comment       = const "Categories of medical devices, organized by the purpose or intended use of the device."
  _url           = const "http://schema.org/MedicalDevicePurpose"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalDevicePurpose.MedicalDevicePurpose)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalDevicePurpose.MedicalDevicePurpose)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIntangible.MedicalIntangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)]