{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.SportsOrganization where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SportsTeam

-- | Represents the collection of all sports organizations, including sports teams, governing bodies, and sports associations.
--
--   [@id@] SportsOrganization
--
--   [@label@] Sports Organization
--
--   [@comment@] Represents the collection of all sports organizations, including sports teams, governing bodies, and sports associations.
--
--   [@ancestors@] @'Thing','Organization'@
--
--   [@subtypes@] @'SportsTeam'@
--
--   [@supertypes@] @'Organization'@
--
--   [@url@] <http://schema.org/SportsOrganization>
data SportsOrganization = SportsOrganization { sport :: Sport
                                             , address :: Address
                                             , aggregateRating :: AggregateRating
                                             , alumni :: Alumni
                                             , areaServed :: AreaServed
                                             , award :: Award
                                             , brand :: Brand
                                             , contactPoint :: ContactPoint
                                             , department :: Department
                                             , dissolutionDate :: DissolutionDate
                                             , duns :: Duns
                                             , email :: Email
                                             , employee :: Employee
                                             , event :: Event
                                             , faxNumber :: FaxNumber
                                             , founder :: Founder
                                             , foundingDate :: FoundingDate
                                             , foundingLocation :: FoundingLocation
                                             , globalLocationNumber :: GlobalLocationNumber
                                             , hasOfferCatalog :: HasOfferCatalog
                                             , hasPOS :: HasPOS
                                             , isicV4 :: IsicV4
                                             , legalName :: LegalName
                                             , location :: Location
                                             , logo :: Logo
                                             , makesOffer :: MakesOffer
                                             , member :: Member
                                             , memberOf :: MemberOf
                                             , naics :: Naics
                                             , numberOfEmployees :: NumberOfEmployees
                                             , owns :: Owns
                                             , parentOrganization :: ParentOrganization
                                             , review :: Review
                                             , seeks :: Seeks
                                             , subOrganization :: SubOrganization
                                             , taxID :: TaxID
                                             , telephone :: Telephone
                                             , vatID :: VatID
                                             , additionalType :: AdditionalType
                                             , alternateName :: AlternateName
                                             , description :: Description
                                             , image :: Image
                                             , mainEntityOfPage :: MainEntityOfPage
                                             , name :: Name
                                             , potentialAction :: PotentialAction
                                             , sameAs :: SameAs
                                             , url :: Url
                                             }
                          deriving (Show, Read, Eq, Typeable)

instance MetaData SportsOrganization where
  _label         = const "Sports Organization"
  _comment_plain = const "Represents the collection of all sports organizations, including sports teams, governing bodies, and sports associations."
  _comment       = const "Represents the collection of all sports organizations, including sports teams, governing bodies, and sports associations."
  _url           = const "http://schema.org/SportsOrganization"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.SportsTeam.SportsTeam)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)]