{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.UserInteraction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Event
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserBlocks
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserCheckins
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserComments
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserDownloads
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserLikes
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserPageVisits
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserPlays
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserPlusOnes
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UserTweets

-- | UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use          Action-based vocabulary, alongside types such as Comment.
--
--   [@id@] UserInteraction
--
--   [@label@] User Interaction
--
--   [@comment@] UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use          <a href=\"http://schema.org/Action\">Action</a>-based vocabulary, alongside types such as <a href=\"http://schema.org/Comment\">Comment</a>.      
--
--   [@ancestors@] @'Thing','Event'@
--
--   [@subtypes@] @'UserBlocks','UserCheckins','UserComments','UserDownloads','UserLikes','UserPageVisits','UserPlays','UserPlusOnes','UserTweets'@
--
--   [@supertypes@] @'Event'@
--
--   [@url@] <http://schema.org/UserInteraction>
data UserInteraction = UserInteraction { aggregateRating :: AggregateRating
                                       , attendee :: Attendee
                                       , doorTime :: DoorTime
                                       , duration :: Duration
                                       , endDate :: EndDate
                                       , eventStatus :: EventStatus
                                       , inLanguage :: InLanguage
                                       , location :: Location
                                       , offers :: Offers
                                       , organizer :: Organizer
                                       , performer :: Performer
                                       , previousStartDate :: PreviousStartDate
                                       , recordedIn :: RecordedIn
                                       , review :: Review
                                       , startDate :: StartDate
                                       , subEvent :: SubEvent
                                       , superEvent :: SuperEvent
                                       , typicalAgeRange :: TypicalAgeRange
                                       , workFeatured :: WorkFeatured
                                       , workPerformed :: WorkPerformed
                                       , additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData UserInteraction where
  _label         = const "User Interaction"
  _comment_plain = const "UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use          Action-based vocabulary, alongside types such as Comment."
  _comment       = const "UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use          <a href=\"http://schema.org/Action\">Action</a>-based vocabulary, alongside types such as <a href=\"http://schema.org/Comment\">Comment</a>.      "
  _url           = const "http://schema.org/UserInteraction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Event.Event)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.UserBlocks.UserBlocks)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UserCheckins.UserCheckins)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UserComments.UserComments)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UserDownloads.UserDownloads)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UserLikes.UserLikes)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UserPageVisits.UserPageVisits)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UserPlays.UserPlays)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UserPlusOnes.UserPlusOnes)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UserTweets.UserTweets)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Event.Event)]