{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.WarrantyPromise where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue

-- | A structured value representing the duration and scope of services that will be provided to a customer free of charge in case of a defect or malfunction of a product.
--
--   [@id@] WarrantyPromise
--
--   [@label@] Warranty Promise
--
--   [@comment@] A structured value representing the duration and scope of services that will be provided to a customer free of charge in case of a defect or malfunction of a product.
--
--   [@ancestors@] @'Thing','Intangible','StructuredValue'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'StructuredValue'@
--
--   [@url@] <http://schema.org/WarrantyPromise>
data WarrantyPromise = WarrantyPromise { durationOfWarranty :: DurationOfWarranty
                                       , warrantyScope :: WarrantyScope
                                       , additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData WarrantyPromise where
  _label         = const "Warranty Promise"
  _comment_plain = const "A structured value representing the duration and scope of services that will be provided to a customer free of charge in case of a defect or malfunction of a product."
  _comment       = const "A structured value representing the duration and scope of services that will be provided to a customer free of charge in case of a defect or malfunction of a product."
  _url           = const "http://schema.org/WarrantyPromise"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]